﻿using System.Web.Mvc;
using System.Web.Security;
using Ninject;
using UserService;
using UserService.Model;

namespace MVCApp.Helper
{
    public class UserAuthAttribute : AuthorizeAttribute
    {
        /// <summary>
        /// 用户服务
        /// </summary>
        [Inject]
        public IUserService CurrentUserService { get; set; }

        public UserInfo CurrentUser
        {
            get { return CurrentUserService.CurrentUser; }
        }

        public override void OnAuthorization(AuthorizationContext filterContext)
        {
            //上下文信息包括控制器、HTTP 内容、请求上下文和路由数据
            base.OnAuthorization(filterContext);
            if (filterContext.Result is HttpUnauthorizedResult)
            {
                var url = string.Format("{0}?returnurl={1}",
                    FormsAuthentication.LoginUrl,
                    filterContext.HttpContext.Server.UrlEncode(filterContext.HttpContext.Request.Url.AbsoluteUri));
                filterContext.Result = new RedirectResult(url);
            }

        }
    }
}