﻿using System;
using System.Threading.Tasks;
using System.Web;
using System.Web.Security;
using LogService;
using Ninject;
using UserService.Dao;
using UserService.Model;

namespace UserService.Impl
{
    public class UserInfoService : IUserService
    {
        private static readonly char splitStr = '/';

        public UserInfo CurrentUser
        {
            get { return GetCurrentUser(); }
        }

        internal ILogService Logger
        {
            get
            {
                using (var kernel = new StandardKernel(new UserServiceModule()))
                {
                    return kernel.Get<ILogService>();
                }
            }
        }

        private UserDao dao = null;

        public UserInfoService()
        {
            dao = new UserDao();
        }

        public void Login(string userName, string pwd)
        {
            //for (int i = 1; i < 6000; i++)
            //{
            //    var num = i;
            //    Task.Factory.StartNew(() =>
            //    {
            //        Logger.AppendLog(num.ToString());
            //    });
            //}
            if (string.IsNullOrWhiteSpace(userName))
            {
                return;
            }
            var user = new UserInfo { Name = userName, Id = long.Parse(DateTime.Now.ToString("yyyyMMddHHmmssfff")) };
            FormsAuthentication.SetAuthCookie(string.Format("{0}{1}{2}", user.Id, splitStr, user.Name), false);
            Logger.AppendLog(string.Format("{0}:id为{1}，用户名为{2}的用户成功登陆系统", DateTime.Now.ToString(), user.Id, user.Name));
        }

        public UserInfo GetUser(long userId)
        {
            var user = userId > 0 ? dao.Get(userId) : null;
            if (user == null)
            {
                Logger.AppendLog(string.Format("ID为{0}的用户不存在", userId));
            }
            else
            {
                Logger.AppendLog(string.Format("ID为{0}的用户,名称为{1}", userId, user.Name));
            }
            return user;
        }

        public UserInfo GetCurrentUser()
        {
            UserInfo userInfo = null;
            if (HttpContext.Current.User != null && !string.IsNullOrWhiteSpace(HttpContext.Current.User.Identity.Name))
            {
                var arr = HttpContext.Current.User.Identity.Name.Split(splitStr);
                userInfo = new UserInfo { Id = long.Parse(arr[0]), Name = arr[1] };
            }
            return userInfo;
        }

        public void Logout()
        {
            var user = GetCurrentUser();
            FormsAuthentication.SignOut();
            if (user != null)
            {
                Logger.AppendLog(string.Format("{0}:id为{1}，用户名为{2}的用户成功退出系统", DateTime.Now, user.Id, user.Name));
            }
        }

    }
}
